ca_kssattr
open | /demo/ca_kssattr.html |
assertTextPresent | setKssAttribute |
click | css=#command .set |
waitForAttribute | command@kssattr:name | value-from-command
assertAttribute | command@kssattr:name | value-from-command
click | css=#command .get |
waitForText | logger | value-from-command
assertText | logger | value-from-command
click | log-reset |
waitForTextNotPresent | logger |
assertTextNotPresent | logger |
click | css=#action .set |
waitForAttribute | action@kssattr:name | value-from-action
assertAttribute | action@kssattr:name | value-from-action
click | css=#action .get |
waitForText | logger | value-from-action
assertText | logger | value-from-action